#######################
AllInPay Sdk for Python
#######################
.. image:: https://travis-ci.org/007gzs/pyallinpay.svg?branch=master
       :target: https://travis-ci.org/007gzs/pyallinpay
.. image:: https://img.shields.io/pypi/v/pyallinpay.svg
       :target: https://pypi.org/project/pyallinpay

通联支付 Python SDK。
`【阅读文档】 <http://pyallinpay.readthedocs.io/zh_CN/latest/>`_。

********
安装
********

目前 PyAllInPay 支持的 Python 环境有 2.7, 3.4, 3.5, 3.6, 3.7 和 pypy。

为了简化安装过程，推荐使用 pip 进行安装

.. code-block:: bash

    pip install pyallinpay

升级 pyallinpay 到新版本::

    pip install -U pyallinpay

如果需要安装 GitHub 上的最新代码::

    pip install https://github.com/007gzs/pyallinpay/archive/master.zip

